@@ -22,6 +22,19 @@ from ..utils import write_toml
 
 __all__ = ["make_project"]
 
+try:
+    from enum import StrEnum
+except ImportError:
+
+    class StrEnum(str, Enum):
+        pass
+
+
+class Branch(StrEnum):
+    main = "main"
+    tailwind = "tailwind"
+    bootstrap = "bootstrap"
+
 
 def _get_user_git_infos() -> tuple[str, str] | None:
     git_config_cmd = ["git", "config", "--global", "--get"]
@@ -48,12 +61,6 @@ def _set_authors_in_pyproject(file: Path, name: str, email: str) -> None:
     write_toml(file, config)
 
 
-class Branch(str, Enum):
-    main = "main"
-    tailwind = "tailwind"
-    bootstrap = "bootstrap"
-
-
 def make_project(
     project_name: str = typer.Argument(..., callback=clean_project_name),
     repo: str = typer.Option(
