@@ -3,7 +3,7 @@ import subprocess
 
 def new_virtualenv():
     commands = [
-        "python -m pip install --upgrade virtualenv",
+        "python -m pip install --upgrade pip virtualenv",
         "python -m virtualenv --prompt . venv",
         "venv/bin/python -m pip install pip-tools hatch",
     ]
@@ -12,7 +12,7 @@ def new_virtualenv():
 
 
 def compile_requirements(groups: list[str]):
-    extras = " --extras " + " --extras ".join(groups) if groups else ""
+    extras = " --extra " + " --extra ".join(groups) if groups else ""
     base_command = "venv/bin/python -m piptools compile -o requirements.txt pyproject.toml --resolver=backtracking"
     subprocess.run(
         [base_command + extras],
